@@ -7,8 +7,7 @@ from trytond.pool import Pool, PoolMeta
 __all__ = ['Template', 'Product']
 
 
-class Template:
-    __metaclass__ = PoolMeta
+class Template(metaclass=PoolMeta):
     __name__ = 'product.template'
 
     @classmethod
@@ -19,8 +18,7 @@ class Template:
             cls.cost_price_method._field.selection.append(new_sel)
 
 
-class Product:
-    __metaclass__ = PoolMeta
+class Product(metaclass=PoolMeta):
     __name__ = 'product.product'
 
     def get_fifo_move(self, quantity=0.0):
@@ -52,7 +50,8 @@ class Product:
             moves = Move.search([
                 ('product', '=', product.id),
                 ('state', '=', 'done'),
-                ('from_location.type', '=', 'supplier'),
+                ('from_location.type', '!=', 'storage'),
+                ('to_location.type', '=', 'storage'),
                 ], offset=offset, limit=limit,
                 order=[('effective_date', 'DESC'), ('id', 'DESC')])
             if not moves:
